==> dde-launcher_3.0.3.orig.tar.xz: dde-launcher-3.0.3/translations/dde-launcher.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>ConfirmUninstallDialog</name>
    <message>
        <location filename="../dialogs/confirmuninstalldialog.cpp" line="12"/>
        <source>All dependencies will be removed together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs/confirmuninstalldialog.cpp" line="15"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs/confirmuninstalldialog.cpp" line="15"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisplayModeFrame</name>
    <message>
        <location filename="../views/displaymodeframe.cpp" line="38"/>
        <source>By name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../views/displaymodeframe.cpp" line="40"/>
        <source>By category (icon)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../views/displaymodeframe.cpp" line="42"/>
        <source>By category (text)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../views/displaymodeframe.cpp" line="44"/>
        <source>By time installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../views/displaymodeframe.cpp" line="46"/>
        <source>By frequency</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LauncherApp</name>
    <message>
        <location filename="../app/launcherapp.cpp" line="47"/>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <location filename="../controller/menucontroller.cpp" line="70"/>
        <source>Open(_O)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="74"/>
        <source>Remove from desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="76"/>
        <source>Send to desktop(_E)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="80"/>
        <source>Remove from dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="82"/>
        <source>Send to dock(_C)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="87"/>
        <source>Remove from startup(_R)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="89"/>
        <source>Add to startup(_A)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="91"/>
        <source>Uninstall</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> dde-launcher_4.3.2.2.orig.tar.xz: dde-launcher-4.3.2.2/translations/dde-launcher.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
